@@ -1,8 +1,12 @@
-"""Plotting boxplots"""
+"""
+Plotting boxplots
+"""
 
 import os
+import attrs
 import pandas as pd
 import plotly.graph_objects as go
+
 from abc import abstractmethod
 
 
@@ -11,13 +15,19 @@ from abc import abstractmethod
 #################################################################################################
 
 class IFBoxPlot:
-    """Interface for the BoxPlot classes
+    """
+    Interface for the BoxPlot classes
     Boxplot is plotting data in order to get a better
     feeling about the dispersion in the data
+
+    Methods
+    -------
+    plot()
+        Responsible for the plotting of the boxplot
     """
 
     @abstractmethod
-    def plot(self): # pragma: no cover
+    def plot(self) -> None: # pragma: no cover
         pass
 
 
@@ -25,18 +35,22 @@ class IFBoxPlot:
 #                                   Boxplot Plotter                                             #
 #################################################################################################
 
+@attrs.define()
 class BoxPlot(IFBoxPlot):
-    """Visualisation of data in form of a boxplot
+    """
+    Visualisation of data in form of a boxplot
     
     Methods
     -------
-        plot()
-            Plots the boxplot and stores it to a user-defined directory `store_dir`
+    plot()
+        Plots the boxplot and stores it to a user-defined directory `store_dir`
     """
+    name: str          = attrs.field(factory = str)
+    data: pd.DataFrame = attrs.field(factory = pd.DataFrame)
+    store_dir: str     = attrs.field(factory = str)
 
     def __init__(self, name: str, data: pd.DataFrame, store_dir: str = "./"):
-        """Initialises the BoxPlot
-
+        """
         Parameters
         ----------
         name : str
@@ -52,7 +66,9 @@ class BoxPlot(IFBoxPlot):
 
 
     def plot(self) -> None:
-        """Plots the boxplot and stores it to a directory"""
+        """ 
+        Plots the boxplot and stores it to a directory 
+        """
         if not os.path.exists(self.store_dir):
             os.mkdir(self.store_dir)
         if not os.path.exists(os.path.join(self.store_dir, "boxplots")):
